==> xld-azure-plugin-7.0.0.jar: xld/azure/virtual_network/create-or-update.py <==
from azure.mgmt.network.models import VirtualNetwork, AddressSpace, DhcpOptions, Subnet
from xld.azure import get_operation_name

from xld.azure.connector import AzureConnector

connector = AzureConnector(deployed.container)

network_client = connector.network_client()

vn_address_space = None

print "AddressSpace {0}".format(deployed.addressPrefixes)

if deployed.addressPrefixes:
    vn_address_space = AddressSpace(
        address_prefixes=deployed.addressPrefixes
    )

vn_dhcp_options = None

print "DhcpOptions {0}".format(deployed.dnsServers)

if deployed.dnsServers:
    vn_dhcp_options = DhcpOptions(
        dns_servers=deployed.dnsServers
    )

vn_subnets = []

print "Subnets {0}".format(deployed.subnets)

for subnet in deployed.subnets:
    print "Adding {0}".format(subnet)
    current_sg = None
    if subnet.networkSecurityGroupName is not None:
        tmp_network_client = connector.network_client()
        print "Looking up network security group '{0}'".format(subnet.networkSecurityGroupName)
        current_sg = tmp_network_client.network_security_groups.get(
            resource_group_name=deployed.resourceGroupName,
            network_security_group_name=subnet.networkSecurityGroupName
        )
        print "Network security group details: {0}".format(current_sg)

    current_rt = None
    if subnet.routeTableName is not None:
        print "Looking up route table '{0}'".format(subnet.routeTableName)
        tmp_network_client = connector.network_client()
        current_rt = tmp_network_client.route_tables.get(
            resource_group_name=deployed.resourceGroupName,
            route_table_name=subnet.routeTableName,
        )
        print "Route table details: {0}".format(current_rt)

    vn_subnets.append(
        Subnet(
            address_prefix=subnet.addressPrefix,
            route_table=current_rt,
            network_security_group=current_sg,
            resource_navigation_links=subnet.resourceNavigationLinks,
            name=subnet.subnetName
        )
    )

network_parameters = VirtualNetwork(
    location=deployed.location,
    tags=deployed.virtualNetworkTags,
    address_space=vn_address_space,
    dhcp_options=vn_dhcp_options,
    subnets=vn_subnets,
    virtual_network_peerings=None
)

print "{0} Virtual Network {1} under Resource Group {2}".format(get_operation_name(previousDeployed),
                                                                deployed.virtualNetworkName, deployed.resourceGroupName)

# asynchronous
op_result = network_client.virtual_networks.create_or_update(
    resource_group_name=deployed.resourceGroupName,
    virtual_network_name=deployed.virtualNetworkName,
    parameters=network_parameters,
    raw=True
)

logger.info("Result: {0}".format(op_result))

==> xld-azure-plugin-7.2.1.jar: xld/azure/virtual_network/create-or-update.py <==
from azure.mgmt.network.models import VirtualNetwork, AddressSpace, DhcpOptions, Subnet
from xld.azure import get_operation_name

from xld.azure.connector import AzureConnector

rg = deployed.container
cloud = rg.container
connector = AzureConnector(cloud)

network_client = connector.network_client()

vn_address_space = None

print "AddressSpace {0}".format(deployed.addressPrefixes)

if deployed.addressPrefixes:
    vn_address_space = AddressSpace(
        address_prefixes=deployed.addressPrefixes
    )

vn_dhcp_options = None

print "DhcpOptions {0}".format(deployed.dnsServers)

if deployed.dnsServers:
    vn_dhcp_options = DhcpOptions(
        dns_servers=deployed.dnsServers
    )

vn_subnets = []

print "Subnets {0}".format(deployed.subnets)

for subnet in deployed.subnets:
    print "Adding {0}".format(subnet)
    current_sg = None
    if subnet.networkSecurityGroupName is not None:
        tmp_network_client = connector.network_client()
        print "Looking up network security group '{0}'".format(subnet.networkSecurityGroupName)
        current_sg = tmp_network_client.network_security_groups.get(
            resource_group_name=rg.resourceGroupName,
            network_security_group_name=subnet.networkSecurityGroupName
        )
        print "Network security group details: {0}".format(current_sg)

    current_rt = None
    if subnet.routeTableName is not None:
        print "Looking up route table '{0}'".format(subnet.routeTableName)
        tmp_network_client = connector.network_client()
        current_rt = tmp_network_client.route_tables.get(
            resource_group_name=rg.resourceGroupName,
            route_table_name=subnet.routeTableName,
        )
        print "Route table details: {0}".format(current_rt)

    vn_subnets.append(
        Subnet(
            address_prefix=subnet.addressPrefix,
            route_table=current_rt,
            network_security_group=current_sg,
            resource_navigation_links=subnet.resourceNavigationLinks,
            name=subnet.subnetName
        )
    )

network_parameters = VirtualNetwork(
    location=deployed.location,
    tags=deployed.virtualNetworkTags,
    address_space=vn_address_space,
    dhcp_options=vn_dhcp_options,
    subnets=vn_subnets,
    virtual_network_peerings=None
)

print "{0} Virtual Network {1} under Resource Group {2}".format(get_operation_name(previousDeployed),
                                                                deployed.virtualNetworkName, rg.resourceGroupName)

# asynchronous
op_result = network_client.virtual_networks.create_or_update(
    resource_group_name=rg.resourceGroupName,
    virtual_network_name=deployed.virtualNetworkName,
    parameters=network_parameters,
    raw=True
)

logger.info("Result: {0}".format(op_result))
